import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/colors/ThemeColors.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/share/DeviceShare.dart';
import 'package:witsystem_device_manage/pages/home/share/ShareType.dart';
import 'package:witsystem_device_manage/pages/home/slock/record/LockRecord.dart';
import 'package:witsystem_device_manage/pages/home/userManage/UserManageWidget.dart';
import 'package:witsystem_device_manage/pages/widget/HomeListData.dart';
import 'package:witsystem_device_manage/pages/widget/HomeTemplet.dart';
import 'package:witsystem_device_plugin/device/DeviceFunctionType.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';

///门锁主页
class SlcokHome extends StatefulWidget {
  final String deviceId;
  final String deviceName;

  /// const SlcokHome({Key? key}) :super(key: key);
  const SlcokHome({Key? key, required this.deviceId, required this.deviceName})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return SlcokHomeState();
  }
}

class SlcokHomeState extends State<SlcokHome> {
  List<HomeListData>? list = [];

  @override
  void initState() {
    super.initState();
    _initListAll();
  }

  ///初始化所有功能列表
  _initListAll() {
    list = [
      HomeListData(
          icon: WitsIcon.yonghu,
          name: S.current.device_userManage,
          widget: UserManageWidget(
              deviceId: widget.deviceId, deviceName: widget.deviceName)),
      HomeListData(
          icon: WitsIcon.jianpan,
          name: S.current.device_passwordManage,
          hardware: DeviceFunctionType.bk),
      HomeListData(
          icon: WitsIcon.zhiwen,
          name: S.current.device_markManage,
          hardware: DeviceFunctionType.mark),
      HomeListData(
          icon: WitsIcon.menka,
          name: S.current.device_cardManage,
          hardware: DeviceFunctionType.card),
      HomeListData(
          icon: WitsIcon.fenxiang,
          name: S.current.device_shareDevice,
          widget: DeviceShareWidget(
              title: S.current.device_shareDevice,
              shareType: ShareType.share,
              deviceId: widget.deviceId,
              deviceName: widget.deviceName)),
      HomeListData(
          icon: WitsIcon.erweima,
          name: S.current.device_shortShare,
          widget: DeviceShareWidget(
              title: S.current.device_shortShare,
              shareType: ShareType.shortShare,
              deviceId: widget.deviceId,
              deviceName: widget.deviceName)),
      HomeListData(
          icon: WitsIcon.jilu,
          name: S.current.device_LockRecord,
          widget: LockRecordWidget(
              deviceName: widget.deviceName, deviceId: widget.deviceId)),
      HomeListData(
          icon: WitsIcon.zhuanrang, name: S.current.device_makeOverDevice),
      HomeListData(
          icon: WitsIcon.shebeishezhi, name: S.current.device_deviceSettings),
      HomeListData(icon: WitsIcon.luyouqi, name: S.current.device_bindRelay),
      HomeListData(icon: WitsIcon.shebei, name: S.current.device_deviceInfo),
      HomeListData(
          icon: WitsIcon.gujianshengji,
          name: S.current.device_ota,
          hardware: DeviceFunctionType.ota),
      HomeListData(icon: WitsIcon.erweima, name: S.current.device_deviceQrCode),
      HomeListData(icon: WitsIcon.saoma, name: S.current.device_scanningCode),
    ];
  }

  @override
  Widget build(BuildContext context) {
    return HomeTempletWidget(
        list: list!,
        deviceId: widget.deviceId,
        deviceName: widget.deviceName,
        itemOnTap: (HomeListData item, int index) {
          if (item.widget == null) return;
          Navigator.of(context).push(MaterialPageRoute(builder: (context) {
            return item.widget!;
          }));
        },
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.min,
          children: [
            GestureDetector(
              onTap: () async {
                try {
                  EasyLoading.show(
                      status: S.of(context).device_openLoading,
                      maskType: EasyLoadingMaskType.clear);
                  await Unlock.instance.bleUnlock(widget.deviceId);
                  EasyLoading.showSuccess(S.of(context).device_openSuccess);
                } on PlatformException catch (e) {
                  EasyLoading.showError(
                      S.of(context).device_openFail(e.message.toString()));
                }
              },
              child: Container(
                width: 180,
                height: 180,
                alignment: Alignment.center,
                decoration: BoxDecoration(
                  color: ThemeColors.transparent,
                  borderRadius: const BorderRadius.all(Radius.circular(90)),
                  border: Border.all(width: 4, color: Colors.white),
                ),
                child: Container(
                    width: 140,
                    height: 140,
                    alignment: Alignment.center,
                    decoration: BoxDecoration(
                      color: ThemeColors.themeItem,
                      borderRadius: const BorderRadius.all(Radius.circular(70)),
                      border: Border.all(style: BorderStyle.none),
                    ),
                    child: const Icon(
                      Icons.lock,
                      color: Colors.white,
                      size: 40,
                    )),
              ),
            ),
            Container(
              margin: const EdgeInsets.fromLTRB(0, 20, 0, 10),
              child: Text("点击上方开门", style: TextStyle(color: Colors.white)),
            ),
          ],
        ));
  }
}
