import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/colors/ThemeColors.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/options/MoreOptions.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';

import 'HomeListData.dart';

///首页模板

class HomeTempletWidget extends StatefulWidget {
  final List<HomeListData> list;

  final String deviceId;
  final String deviceName;

  final Widget child;

  final Function(HomeListData item, int index)? itemOnTap;

  const HomeTempletWidget(
      {Key? key,
      required this.deviceId,
      required this.list,
      required this.child,
      required this.deviceName,
      this.itemOnTap})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return HomeTempletState();
  }
}

class HomeTempletState extends State<HomeTempletWidget> {
  @override
  void initState() {
    super.initState();
    _filterItem();
  }

  ///筛选支持的功能
  _filterItem() async {
    List<HomeListData> list = [];
    int length = widget.list.length;
    for (int i = 0; i < length; i++) {
      var hardware = widget.list[i].hardware;
      if (hardware == null ||
          await DeviceManage.instance
              .isDeviceFunction(widget.deviceId, hardware)) {
        list.add(widget.list[i]);
      }
    }
    if (list.length < 9) {
      setState(() {});
      return; //判断如果小于7直接结束
    }
    var sublist = list.sublist(7); //分割出第8个以后的数据包含第8个
    list.removeRange(7, list.length); //删除第8个以后的数据包含第8个
    list.add(HomeListData(
        //给第8的位置添加更多选项
        icon: WitsIcon.gengduo,
        name: S.current.device_moreOptions,
        widget: MoreOptionsWidget(list: sublist)));
    widget.list.clear();
    widget.list.addAll(list);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        //title: Text(S.of(context).device_lockHome),
        title: Text(widget.deviceName),
      ),
      body: Container(
        height: double.infinity,
        width: double.infinity,
        color: ThemeColors.theme,
        child: Column(
          children: [
            Expanded(
              flex: 1,
              child: widget.child,
            ),
            Container(
              margin: const EdgeInsets.fromLTRB(10, 0, 10, 0),
              padding: const EdgeInsets.all(6),
              decoration: const BoxDecoration(
                color: ThemeColors.themeItem,
                borderRadius: BorderRadius.all(Radius.circular(4.0)),
              ),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  Text(S.of(context).device_battery("10%"),
                      style:
                          const TextStyle(color: Colors.white, fontSize: 12)),
                  Text(S.of(context).device_auth('管理员'),
                      style: const TextStyle(color: Colors.white, fontSize: 12))
                ],
              ),
            ),
            Container(
                height: 180,
                padding: const EdgeInsets.fromLTRB(0, 10, 0, 0),
                margin: const EdgeInsets.all(10),
                decoration: const BoxDecoration(
                  color: ThemeColors.themeItem,
                  borderRadius: BorderRadius.all(Radius.circular(4.0)),
                ),
                child: GridView.builder(
                    gridDelegate:
                        const SliverGridDelegateWithFixedCrossAxisCount(
                            crossAxisCount: 4,
                            crossAxisSpacing: 10,
                            mainAxisSpacing: 10,
                            childAspectRatio: 1.2),
                    itemCount: widget.list.length,
                    itemBuilder: (context, index) {
                      return GestureDetector(
                        onTap: () {
                          if (widget.itemOnTap != null) {
                            widget.itemOnTap!(widget.list[index], index);
                          }
                        },
                        child: Container(
                          padding: const EdgeInsets.fromLTRB(5, 5, 5, 15),
                          child: Column(
                            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                            children: [
                              Icon(
                                widget.list[index].icon,
                                size: 30,
                                color: Colors.white,
                              ),
                              Text(
                                widget.list[index].name,
                                style: const TextStyle(
                                    color: Colors.white, fontSize: 12),
                              )
                            ],
                          ),
                        ),
                      );
                    })),
          ],
        ),
      ),
    );
  }
}
