library witsystem_device_manage;

import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/pages/home/slock/SlcokHome.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/colors/ThemeColors.dart';

class WitsystemDeviceListWidget extends StatefulWidget {

  const WitsystemDeviceListWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return DeviceListState();
  }
}

class DeviceListState extends State<WitsystemDeviceListWidget> {
  List deviceList = [];

  @override
  void initState() {
    super.initState();
    init();
  }

  init() async {
    var list = await DeviceManage.instance.deviceList();
    print(list);
    setState(() {
      deviceList.addAll(list);
    });
  }

  ///区分不同类型显示不同的item
  Widget _deviceType(Map<String, dynamic> device) {
    switch (device['device']['type']) {
      case "Slock":
        return _slcokWidget(device);

      case "Ammet":
        return _ammetWidget(device);

      case "Relay":
        return _relayWidget(device);

      case "Water":
        return _waterWidget(device);

      default:
        return _defaultWidget(device);
    }
  }

  ///门锁
  Widget _slcokWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.mensuo,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        GestureDetector(
          child: const Padding(
            padding: EdgeInsets.all(10),
            child: Icon(
              WitsIcon.open,
              color: Colors.red,
              size: 20,
            ),
          ),
          onTap: () async {
            try {
              EasyLoading.show(
                  status: S.of(context).device_openLoading,
                  maskType: EasyLoadingMaskType.clear);
              await Unlock.instance.bleUnlock(device['device']['deviceId']);
              EasyLoading.showSuccess(S.of(context).device_openSuccess);
            } on PlatformException catch (e) {
              EasyLoading.showError(
                  S.of(context).device_openFail(e.message.toString()));
            }
          },
        )
      ],
    );
  }

  ///电表
  Widget _ammetWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.dianbiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesAmmet']['balance']}",
            style: const TextStyle(color: Colors.white, fontSize: 12))
      ],
    );
  }

  ///中继
  Widget _relayWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.luyouqi,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Icon(WitsIcon.xinhao)
      ],
    );
  }

  ///水表
  Widget _waterWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shuibiao,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        Text("${device['device']['devicesWater']['balance']}",
            style: const TextStyle(color: Colors.white))
      ],
    );
  }

  ///默认
  Widget _defaultWidget(Map<String, dynamic> device) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Icon(
          WitsIcon.shebei,
          color: (device['device']['onLine'] ? Colors.green : Colors.red),
          size: 40,
        ),
        const Text("...", style: TextStyle(color: Colors.white))
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: ThemeColors.theme,
      padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
      child: GridView.builder(
          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: 2,
              crossAxisSpacing: 10,
              mainAxisSpacing: 10,
              childAspectRatio: 1.5),
          itemCount: deviceList.length,
          itemBuilder: (context, index) {
            return GestureDetector(
              onTap: () {
                Navigator.of(context)
                    .push(MaterialPageRoute(builder: (BuildContext context) {
                  return SlcokHome(
                      deviceId: deviceList[index]['device']['deviceId'],deviceName:deviceList[index]['device']['deviceName']);
                }));
              },
              child: Container(
                decoration: BoxDecoration(
                  color: ThemeColors.themeItem,
                  borderRadius: const BorderRadius.all(Radius.circular(4.0)),
                  //设置四周圆角 角度
                  border: Border.all(
                      width: 1, color: ThemeColors.themeItem), //设置四周边框
                ),
                padding: const EdgeInsets.fromLTRB(5, 5, 5, 15),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    // Image.asset("images/t3.png",package: "witsystem_theme_a"),
                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,

                      children: [
                        Expanded(
                          flex: 1,
                          child: Text("${deviceList[index]['deviceName']}",
                              maxLines: 1,
                              overflow: TextOverflow.ellipsis,
                              style: const TextStyle(
                                color: Colors.white,
                                fontSize: 12,
                              )),
                        ),
                        Text(
                            deviceList[index]['device']['onLine']
                                ? S.of(context).device_onLine
                                : S.of(context).device_offLine,
                            style: const TextStyle(
                                color: Colors.white, fontSize: 12)),
                      ],
                    ),
                    _deviceType(deviceList[index]),
                  ],
                ),
              ),
            );
          }),
    );
  }
}
